``eradiate.spectral``
=====================

.. automodule:: eradiate.spectral

.. py:currentmodule:: eradiate.spectral

Spectral indexes
----------------

.. autosummary::
   :toctree: generated/autosummary/

   SpectralIndex
   MonoSpectralIndex
   CKDSpectralIndex

CKD spectral quadrature specification strategies
------------------------------------------------

.. autosummary::
   :toctree: generated/autosummary/

   QuadSpec
   QuadSpecFixed
   QuadSpecMinError
   QuadSpecErrorThreshold

Utility containers
------------------

.. autosummary::
   :toctree: generated/autosummary/

   WavelengthSet
   Bin
   BinSet
